import { copy } from "@/utils/utils"
import { ColumnsType } from "antd/es/table"
import { LINKTYPEEle } from "./const"
import { Button, Flex, Popover } from "antd"
import Details from "./details"


export function bookLinkTableConfig(isSelect: boolean, handleCopy?: (value: any) => void): ColumnsType<any> {

    const arr: ColumnsType<any> = [
        {
            title: '书城',
            dataIndex: 'platformName',
            key: 'platformName',
            align: 'center',
            width: 80,
            ellipsis: true,
            fixed: 'left',
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value}</span>
            }
        },
        {
            title: '公众号',
            dataIndex: 'mpAccountName',
            key: 'mpAccountName',
            align: 'center',
            width: 80,
            fixed: 'left',
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value}</span>
            }
        },
        {
            title: '渠道名称',
            dataIndex: 'channelName',
            key: 'channelName',
            width: 110,
            ellipsis: true,
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value || '--'}</span>
            }
        },
        {
            title: '推广类型',
            dataIndex: 'channelType',
            key: 'channelType',
            align: 'center',
            width: 80,
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value === 1 ? '外部' : value === 2 ? '内部' : '--'}</span>
            }
        },
        {
            title: '链接类型',
            dataIndex: 'linkType',
            key: 'linkType',
            align: 'center',
            width: 120,
            render: (value) => {
                return LINKTYPEEle[value] || '--'
            }
        },
        {
            title: '生成链接',
            dataIndex: 'link',
            key: 'link',
            width: 200,
            ellipsis: true,
            render: (value) => {
                return value ? <a style={{ fontSize: 12 }} onClick={() => copy(value)}>{value}</a> : '--'
            }
        },
        {
            title: '小程序Appid',
            dataIndex: 'wxAppid',
            key: 'wxAppid',
            width: 80,
            ellipsis: true,
            render: (value) => {
                return value ? <a style={{ fontSize: 12 }} onClick={() => copy(value)}>{value}</a> : '--'
            }
        },
        {
            title: '小程序链接',
            dataIndex: 'miniappPagePath',
            key: 'miniappPagePath',
            width: 200,
            ellipsis: true,
            render: (value) => {
                return value ? <a style={{ fontSize: 12 }} onClick={() => copy(value)}>{value}</a> : '--'
            }
        },
        {
            title: '创建人',
            dataIndex: 'createByInfo',
            key: 'createByInfo',
            align: 'center',
            width: 80,
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value?.nickname}</span>
            }
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            key: 'createTime',
            align: 'center',
            width: 140,
            render: (value) => {
                return <span style={{ fontSize: 12 }}>{value}</span>
            }
        },
        {
            title: '详情',
            dataIndex: 'cz',
            key: 'cz',
            align: 'center',
            width: 60,
            fixed: 'right',
            render: (_, records) => {
                return <Flex gap={4} justify='center'>
                    <Popover
                        placement="left"
                        content={<Details linkType={records.linkType} linkContent={records.linkContext} />}
                        styles={{ body: { width: 300, overflow: 'hidden', overflowY: 'auto', maxHeight: 400 } }}
                    >
                        <Button type="link" style={{ padding: 0, height: 'auto' }}>详情</Button>
                    </Popover>
                    {!isSelect && <Button type="link" style={{ padding: 0, height: 'auto' }} onClick={() => handleCopy(records)}>复制</Button>}
                </Flex>
            }
        },
    ]
    return arr
}